@@ -2,7 +2,7 @@
 //============================================================+
 // File name   : example_012.php
 // Begin       : 2008-03-04
-// Last Update : 2010-05-20
+// Last Update : 2013-05-14
 //
 // Description : Example 012 for TCPDF class
 //               Graphic Functions
@@ -11,10 +11,7 @@
 //
 // (c) Copyright:
 //               Nicola Asuni
-//               Tecnick.com s.r.l.
-//               Via Della Pace, 11
-//               09044 Quartucciu (CA)
-//               ITALY
+//               Tecnick.com LTD
 //               www.tecnick.com
 //               info@tecnick.com
 //============================================================+
@@ -24,48 +21,48 @@
  * @package com.tecnick.tcpdf
  * @abstract TCPDF - Example: Graphic Functions
  * @author Nicola Asuni
- * @copyright 2004-2010 Nicola Asuni - Tecnick.com S.r.l (www.tecnick.com) Via Della Pace, 11 - 09044 - Quartucciu (CA) - ITALY - www.tecnick.com - info@tecnick.com
- * @link http://tcpdf.org
- * @license http://www.gnu.org/copyleft/lesser.html LGPL
  * @since 2008-03-04
  */
 
-require_once('../config/lang/eng.php');
-require_once('../tcpdf.php');
+// Include the main TCPDF library (search for installation path).
+require_once('tcpdf_include.php');
 
 // create new PDF document
 $pdf = new TCPDF(PDF_PAGE_ORIENTATION, PDF_UNIT, PDF_PAGE_FORMAT, true, 'UTF-8', false);
 
 // set document information
-$pdf->SetCreator(PDF_CREATOR);
-$pdf->SetAuthor('Nicola Asuni');
-$pdf->SetTitle('TCPDF Example 012');
-$pdf->SetSubject('TCPDF Tutorial');
-$pdf->SetKeywords('TCPDF, PDF, example, test, guide');
+$pdf->setCreator(PDF_CREATOR);
+$pdf->setAuthor('Nicola Asuni');
+$pdf->setTitle('TCPDF Example 012');
+$pdf->setSubject('TCPDF Tutorial');
+$pdf->setKeywords('TCPDF, PDF, example, test, guide');
 
 // disable header and footer
 $pdf->setPrintHeader(false);
 $pdf->setPrintFooter(false);
 
 // set default monospaced font
-$pdf->SetDefaultMonospacedFont(PDF_FONT_MONOSPACED);
+$pdf->setDefaultMonospacedFont(PDF_FONT_MONOSPACED);
 
-//set margins
-$pdf->SetMargins(PDF_MARGIN_LEFT, PDF_MARGIN_TOP, PDF_MARGIN_RIGHT);
+// set margins
+$pdf->setMargins(PDF_MARGIN_LEFT, PDF_MARGIN_TOP, PDF_MARGIN_RIGHT);
 
-//set auto page breaks
-$pdf->SetAutoPageBreak(TRUE, PDF_MARGIN_BOTTOM);
+// set auto page breaks
+$pdf->setAutoPageBreak(TRUE, PDF_MARGIN_BOTTOM);
 
-//set image scale factor
+// set image scale factor
 $pdf->setImageScale(PDF_IMAGE_SCALE_RATIO);
 
-//set some language-dependent strings
-$pdf->setLanguageArray($l);
+// set some language-dependent strings (optional)
+if (@file_exists(dirname(__FILE__).'/lang/eng.php')) {
+	require_once(dirname(__FILE__).'/lang/eng.php');
+	$pdf->setLanguageArray($l);
+}
 
 // ---------------------------------------------------------
 
 // set font
-$pdf->SetFont('helvetica', '', 10);
+$pdf->setFont('helvetica', '', 10);
 
 // add a page
 $pdf->AddPage();
@@ -94,77 +91,77 @@ $pdf->Rect(145, 10, 40, 20, 'D', array('all' => $style3));
 
 // Curve
 $pdf->Text(5, 34, 'Curve examples');
-$pdf->Curve(5, 40, 30, 55, 70, 45, 60, 75, null, $style6);
+$pdf->Curve(5, 40, 30, 55, 70, 45, 60, 75, '', $style6);
 $pdf->Curve(80, 40, 70, 75, 150, 45, 100, 75, 'F', $style6);
 $pdf->Curve(140, 40, 150, 55, 180, 45, 200, 75, 'DF', $style6, array(200, 220, 200));
 
 // Circle and ellipse
 $pdf->Text(5, 79, 'Circle and ellipse examples');
-$pdf->SetLineStyle($style5);
+$pdf->setLineStyle($style5);
 $pdf->Circle(25,105,20);
-$pdf->Circle(25,105,10, 90, 180, null, $style6);
+$pdf->Circle(25,105,10, 90, 180, '', $style6);
 $pdf->Circle(25,105,10, 270, 360, 'F');
 $pdf->Circle(25,105,10, 270, 360, 'C', $style6);
 
-$pdf->SetLineStyle($style5);
+$pdf->setLineStyle($style5);
 $pdf->Ellipse(100,103,40,20);
-$pdf->Ellipse(100,105,20,10, 0, 90, 180, null, $style6);
+$pdf->Ellipse(100,105,20,10, 0, 90, 180, '', $style6);
 $pdf->Ellipse(100,105,20,10, 0, 270, 360, 'DF', $style6);
 
-$pdf->SetLineStyle($style5);
+$pdf->setLineStyle($style5);
 $pdf->Ellipse(175,103,30,15,45);
-$pdf->Ellipse(175,105,15,7.50, 45, 90, 180, null, $style6);
+$pdf->Ellipse(175,105,15,7.50, 45, 90, 180, '', $style6);
 $pdf->Ellipse(175,105,15,7.50, 45, 270, 360, 'F', $style6, array(220, 200, 200));
 
 // Polygon
 $pdf->Text(5, 129, 'Polygon examples');
-$pdf->SetLineStyle(array('width' => 0.5, 'cap' => 'butt', 'join' => 'miter', 'dash' => 0, 'color' => array(0, 0, 0)));
+$pdf->setLineStyle(array('width' => 0.5, 'cap' => 'butt', 'join' => 'miter', 'dash' => 0, 'color' => array(0, 0, 0)));
 $pdf->Polygon(array(5,135,45,135,15,165));
 $pdf->Polygon(array(60,135,80,135,80,155,70,165,50,155), 'DF', array($style6, $style7, $style7, 0, $style6), array(220, 200, 200));
 $pdf->Polygon(array(120,135,140,135,150,155,110,155), 'D', array($style6, 0, $style7, $style6));
 $pdf->Polygon(array(160,135,190,155,170,155,200,160,160,165), 'DF', array('all' => $style6), array(220, 220, 220));
 
 // Polygonal Line
-$pdf->SetLineStyle(array('width' => 0.5, 'cap' => 'butt', 'join' => 'miter', 'dash' => 0, 'color' => array(0, 0, 164)));
+$pdf->setLineStyle(array('width' => 0.5, 'cap' => 'butt', 'join' => 'miter', 'dash' => 0, 'color' => array(0, 0, 164)));
 $pdf->PolyLine(array(80,165,90,160,100,165,110,160,120,165,130,160,140,165), 'D', array(), array());
 
 // Regular polygon
 $pdf->Text(5, 169, 'Regular polygon examples');
-$pdf->SetLineStyle($style5);
+$pdf->setLineStyle($style5);
 $pdf->RegularPolygon(20, 190, 15, 6, 0, 1, 'F');
 $pdf->RegularPolygon(55, 190, 15, 6);
-$pdf->RegularPolygon(55, 190, 10, 6, 45, 0, 'DF', array($style6, 0, $style7, 0, $style7, $style7));
-$pdf->RegularPolygon(90, 190, 15, 3, 0, 1, 'DF', array('all' => $style5), array(200, 220, 200), 'F', array(255, 200, 200));
-$pdf->RegularPolygon(125, 190, 15, 4, 30, 1, null, array('all' => $style5), null, null, $style6);
+$pdf->RegularPolygon(55, 190, 10, 6, 45, false, 'DF', array($style6, 0, $style7, 0, $style7, $style7));
+$pdf->RegularPolygon(90, 190, 15, 3, 0, true, 'DF', array('all' => $style5), array(200, 220, 200), 'F', array(255, 200, 200));
+$pdf->RegularPolygon(125, 190, 15, 4, 30, true, '', array('all' => $style5), array(), '', $style6);
 $pdf->RegularPolygon(160, 190, 15, 10);
 
 // Star polygon
 $pdf->Text(5, 209, 'Star polygon examples');
-$pdf->SetLineStyle($style5);
+$pdf->setLineStyle($style5);
 $pdf->StarPolygon(20, 230, 15, 20, 3, 0, 1, 'F');
 $pdf->StarPolygon(55, 230, 15, 12, 5);
-$pdf->StarPolygon(55, 230, 7, 12, 5, 45, 0, 'DF', array('all' => $style7), array(220, 220, 200), 'F', array(255, 200, 200));
-$pdf->StarPolygon(90, 230, 15, 20, 6, 0, 1, 'DF', array('all' => $style5), array(220, 220, 200), 'F', array(255, 200, 200));
-$pdf->StarPolygon(125, 230, 15, 5, 2, 30, 1, null, array('all' => $style5), null, null, $style6);
+$pdf->StarPolygon(55, 230, 7, 12, 5, 45, false, 'DF', array('all' => $style7), array(220, 220, 200), 'F', array(255, 200, 200));
+$pdf->StarPolygon(90, 230, 15, 20, 6, 0, true, 'DF', array('all' => $style5), array(220, 220, 200), 'F', array(255, 200, 200));
+$pdf->StarPolygon(125, 230, 15, 5, 2, 30, true, '', array('all' => $style5), array(), '', $style6);
 $pdf->StarPolygon(160, 230, 15, 10, 3);
 $pdf->StarPolygon(160, 230, 7, 50, 26);
 
 // Rounded rectangle
 $pdf->Text(5, 249, 'Rounded rectangle examples');
-$pdf->SetLineStyle(array('width' => 0.5, 'cap' => 'butt', 'join' => 'miter', 'dash' => 0, 'color' => array(0, 0, 0)));
+$pdf->setLineStyle(array('width' => 0.5, 'cap' => 'butt', 'join' => 'miter', 'dash' => 0, 'color' => array(0, 0, 0)));
 $pdf->RoundedRect(5, 255, 40, 30, 3.50, '1111', 'DF');
 $pdf->RoundedRect(50, 255, 40, 30, 6.50, '1000');
-$pdf->RoundedRect(95, 255, 40, 30, 10.0, '1111', null, $style6);
+$pdf->RoundedRect(95, 255, 40, 30, 10.0, '1111', '', $style6);
 $pdf->RoundedRect(140, 255, 40, 30, 8.0, '0101', 'DF', $style6, array(200, 200, 200));
 
 // Arrows
 $pdf->Text(185, 249, 'Arrows');
-$pdf->SetLineStyle($style5);
-$pdf->SetFillColor(255, 0, 0);
-$pdf->Arrow($x0=200, $y0=280, $x1=185, $y1=266, $head_style=0, $arm_size=5, $arm_angle=15);
-$pdf->Arrow($x0=200, $y0=280, $x1=190, $y1=263, $head_style=1, $arm_size=5, $arm_angle=15);
-$pdf->Arrow($x0=200, $y0=280, $x1=195, $y1=261, $head_style=2, $arm_size=5, $arm_angle=15);
-$pdf->Arrow($x0=200, $y0=280, $x1=200, $y1=260, $head_style=3, $arm_size=5, $arm_angle=15);
+$pdf->setLineStyle($style5);
+$pdf->setFillColor(255, 0, 0);
+$pdf->Arrow(200, 280, 185, 266, 0, 5, 15);
+$pdf->Arrow(200, 280, 190, 263, 1, 5, 15);
+$pdf->Arrow(200, 280, 195, 261, 2, 5, 15);
+$pdf->Arrow(200, 280, 200, 260, 3, 5, 15);
 
 // - . - . - . - . - . - . - . - . - . - . - . - . - . - . -
 
@@ -180,22 +177,22 @@ $xc=100;
 $yc=100;
 
 // X Y axis
-$pdf->SetDrawColor(200, 200, 200);
+$pdf->setDrawColor(200, 200, 200);
 $pdf->Line($xc-50, $yc, $xc+50, $yc);
 $pdf->Line($xc, $yc-50, $xc, $yc+50);
 
 // ellipse axis
-$pdf->SetDrawColor(200, 220, 255);
+$pdf->setDrawColor(200, 220, 255);
 $pdf->Line($xc-50, $yc-50, $xc+50, $yc+50);
 $pdf->Line($xc-50, $yc+50, $xc+50, $yc-50);
 
 // ellipse
-$pdf->SetDrawColor(200, 255, 200);
-$pdf->Ellipse($xc, $yc, $rx=30, $ry=15, $angle=45, $astart=0, $afinish=360, $style='D', $line_style=array(), $fill_color=array(), $nc=2);
+$pdf->setDrawColor(200, 255, 200);
+$pdf->Ellipse($xc, $yc, 30, 15, 45, 0, 360, 'D', array(), array(), 2);
 
 // ellipse arc
-$pdf->SetDrawColor(255, 0, 0);
-$pdf->Ellipse($xc, $yc, $rx=30, $ry=15, $angle=45, $astart=45, $afinish=90, $style='D', $line_style=array(), $fill_color=array(), $nc=2);
+$pdf->setDrawColor(255, 0, 0);
+$pdf->Ellipse($xc, $yc, 30, 15, 45, 45, 90, 'D', array(), array(), 2);
 
 
 // ---------------------------------------------------------
@@ -206,4 +203,3 @@ $pdf->Output('example_012.pdf', 'I');
 //============================================================+
 // END OF FILE
 //============================================================+
-?>
