@@ -2,7 +2,7 @@
 //============================================================+
 // File name   : example_014.php
 // Begin       : 2008-03-04
-// Last Update : 2010-06-07
+// Last Update : 2013-05-14
 //
 // Description : Example 014 for TCPDF class
 //               Javascript Form and user rights (only works on Adobe Acrobat)
@@ -11,10 +11,7 @@
 //
 // (c) Copyright:
 //               Nicola Asuni
-//               Tecnick.com s.r.l.
-//               Via Della Pace, 11
-//               09044 Quartucciu (CA)
-//               ITALY
+//               Tecnick.com LTD
 //               www.tecnick.com
 //               info@tecnick.com
 //============================================================+
@@ -24,48 +21,49 @@
  * @package com.tecnick.tcpdf
  * @abstract TCPDF - Example: Javascript Form and user rights (only works on Adobe Acrobat)
  * @author Nicola Asuni
- * @copyright 2004-2009 Nicola Asuni - Tecnick.com S.r.l (www.tecnick.com) Via Della Pace, 11 - 09044 - Quartucciu (CA) - ITALY - www.tecnick.com - info@tecnick.com
- * @link http://tcpdf.org
- * @license http://www.gnu.org/copyleft/lesser.html LGPL
  * @since 2008-03-04
  */
 
-require_once('../config/lang/eng.php');
-require_once('../tcpdf.php');
+
+// Include the main TCPDF library (search for installation path).
+require_once('tcpdf_include.php');
 
 // create new PDF document
 $pdf = new TCPDF(PDF_PAGE_ORIENTATION, PDF_UNIT, PDF_PAGE_FORMAT, true, 'UTF-8', false);
 
 // set document information
-$pdf->SetCreator(PDF_CREATOR);
-$pdf->SetAuthor('Nicola Asuni');
-$pdf->SetTitle('TCPDF Example 014');
-$pdf->SetSubject('TCPDF Tutorial');
-$pdf->SetKeywords('TCPDF, PDF, example, test, guide');
+$pdf->setCreator(PDF_CREATOR);
+$pdf->setAuthor('Nicola Asuni');
+$pdf->setTitle('TCPDF Example 014');
+$pdf->setSubject('TCPDF Tutorial');
+$pdf->setKeywords('TCPDF, PDF, example, test, guide');
 
 // set default header data
-$pdf->SetHeaderData(PDF_HEADER_LOGO, PDF_HEADER_LOGO_WIDTH, PDF_HEADER_TITLE.' 014', PDF_HEADER_STRING);
+$pdf->setHeaderData(PDF_HEADER_LOGO, PDF_HEADER_LOGO_WIDTH, PDF_HEADER_TITLE.' 014', PDF_HEADER_STRING);
 
 // set header and footer fonts
 $pdf->setHeaderFont(Array(PDF_FONT_NAME_MAIN, '', PDF_FONT_SIZE_MAIN));
 $pdf->setFooterFont(Array(PDF_FONT_NAME_DATA, '', PDF_FONT_SIZE_DATA));
 
 // set default monospaced font
-$pdf->SetDefaultMonospacedFont(PDF_FONT_MONOSPACED);
+$pdf->setDefaultMonospacedFont(PDF_FONT_MONOSPACED);
 
-//set margins
-$pdf->SetMargins(PDF_MARGIN_LEFT, PDF_MARGIN_TOP, PDF_MARGIN_RIGHT);
-$pdf->SetHeaderMargin(PDF_MARGIN_HEADER);
-$pdf->SetFooterMargin(PDF_MARGIN_FOOTER);
+// set margins
+$pdf->setMargins(PDF_MARGIN_LEFT, PDF_MARGIN_TOP, PDF_MARGIN_RIGHT);
+$pdf->setHeaderMargin(PDF_MARGIN_HEADER);
+$pdf->setFooterMargin(PDF_MARGIN_FOOTER);
 
-//set auto page breaks
-$pdf->SetAutoPageBreak(TRUE, PDF_MARGIN_BOTTOM);
+// set auto page breaks
+$pdf->setAutoPageBreak(TRUE, PDF_MARGIN_BOTTOM);
 
-//set image scale factor
+// set image scale factor
 $pdf->setImageScale(PDF_IMAGE_SCALE_RATIO);
 
-//set some language-dependent strings
-$pdf->setLanguageArray($l);
+// set some language-dependent strings (optional)
+if (@file_exists(dirname(__FILE__).'/lang/eng.php')) {
+	require_once(dirname(__FILE__).'/lang/eng.php');
+	$pdf->setLanguageArray($l);
+}
 
 // ---------------------------------------------------------
 
@@ -73,7 +71,7 @@ $pdf->setLanguageArray($l);
 $pdf->setFontSubsetting(false);
 
 // set font
-$pdf->SetFont('helvetica', '', 10, '', false);
+$pdf->setFont('helvetica', '', 10, '', false);
 
 // add a page
 $pdf->AddPage();
@@ -87,11 +85,11 @@ This name allows to manipulate them via JavaScript in order to perform some vali
 // set default form properties
 $pdf->setFormDefaultProp(array('lineWidth'=>1, 'borderStyle'=>'solid', 'fillColor'=>array(255, 255, 200), 'strokeColor'=>array(255, 128, 128)));
 
-$pdf->SetFont('helvetica', 'BI', 18);
+$pdf->setFont('helvetica', 'BI', 18);
 $pdf->Cell(0, 5, 'Example of Form', 0, 1, 'C');
 $pdf->Ln(10);
 
-$pdf->SetFont('helvetica', '', 12);
+$pdf->setFont('helvetica', '', 12);
 
 // First name
 $pdf->Cell(35, 5, 'First name:');
@@ -105,12 +103,12 @@ $pdf->Ln(6);
 
 // Gender
 $pdf->Cell(35, 5, 'Gender:');
-//$pdf->ComboBox('gender', 10, 5, array('', 'M', 'F'));
 $pdf->ComboBox('gender', 30, 5, array(array('', '-'), array('M', 'Male'), array('F', 'Female')));
 $pdf->Ln(6);
 
 // Drink
 $pdf->Cell(35, 5, 'Drink:');
+//$pdf->RadioButton('drink', 5, array('readonly' => 'true'), array(), 'Water');
 $pdf->RadioButton('drink', 5, array(), array(), 'Water');
 $pdf->Cell(35, 5, 'Water');
 $pdf->Ln(6);
@@ -121,34 +119,38 @@ $pdf->Ln(6);
 $pdf->Cell(35, 5, '');
 $pdf->RadioButton('drink', 5, array(), array(), 'Wine');
 $pdf->Cell(35, 5, 'Wine');
+$pdf->Ln(6);
+$pdf->Cell(35, 5, '');
+$pdf->RadioButton('drink', 5, array(), array(), 'Milk');
+$pdf->Cell(35, 5, 'Milk');
 $pdf->Ln(10);
 
+// Newsletter
+$pdf->Cell(35, 5, 'Newsletter:');
+$pdf->CheckBox('newsletter', 5, true, array(), array(), 'OK');
+
+$pdf->Ln(10);
+// Address
+$pdf->Cell(35, 5, 'Address:');
+$pdf->TextField('address', 60, 18, array('multiline'=>true, 'lineWidth'=>0, 'borderStyle'=>'none'), array('v'=>'Lorem ipsum dolor sit amet, consectetur adipiscing elit.', 'dv'=>'Lorem ipsum dolor sit amet, consectetur adipiscing elit.'));
+$pdf->Ln(19);
+
 // Listbox
 $pdf->Cell(35, 5, 'List:');
 $pdf->ListBox('listbox', 60, 15, array('', 'item1', 'item2', 'item3', 'item4', 'item5', 'item6', 'item7'), array('multipleSelection'=>'true'));
 $pdf->Ln(20);
 
-// Adress
-$pdf->Cell(35, 5, 'Address:');
-$pdf->TextField('address', 60, 18, array('multiline'=>true));
-$pdf->Ln(19);
-
 // E-mail
 $pdf->Cell(35, 5, 'E-mail:');
 $pdf->TextField('email', 50, 5);
 $pdf->Ln(6);
 
-// Newsletter
-$pdf->Cell(35, 5, 'Newsletter:');
-$pdf->CheckBox('newsletter', 5, true, array(), array(), 'OK');
-$pdf->Ln(10);
-
 // Date of the day
 $pdf->Cell(35, 5, 'Date:');
 $pdf->TextField('date', 30, 5, array(), array('v'=>date('Y-m-d'), 'dv'=>date('Y-m-d')));
 $pdf->Ln(10);
 
-$pdf->SetX(50);
+$pdf->setX(50);
 
 // Button to validate and print
 $pdf->Button('print', 30, 10, 'Print', 'Print()', array('lineWidth'=>2, 'borderStyle'=>'beveled', 'fillColor'=>array(128, 196, 255), 'strokeColor'=>array(64, 64, 64)));
@@ -159,7 +161,6 @@ $pdf->Button('reset', 30, 10, 'Reset', array('S'=>'ResetForm'), array('lineWidth
 // Submit Button
 $pdf->Button('submit', 30, 10, 'Submit', array('S'=>'SubmitForm', 'F'=>'http://localhost/printvars.php', 'Flags'=>array('ExportFormat')), array('lineWidth'=>2, 'borderStyle'=>'beveled', 'fillColor'=>array(128, 196, 255), 'strokeColor'=>array(64, 64, 64)));
 
-
 // Form validation functions
 $js = <<<EOD
 function CheckField(name,message) {
@@ -186,9 +187,8 @@ $pdf->IncludeJS($js);
 // ---------------------------------------------------------
 
 //Close and output PDF document
-$pdf->Output('example_014.pdf', 'I');
+$pdf->Output('example_014.pdf', 'D');
 
 //============================================================+
 // END OF FILE
 //============================================================+
-?>
