@@ -2,19 +2,16 @@
 //============================================================+
 // File name   : example_024.php
 // Begin       : 2008-03-04
-// Last Update : 2010-05-20
+// Last Update : 2013-05-14
 //
 // Description : Example 024 for TCPDF class
-//               Object Visibility
+//               Object Visibility and Layers
 //
 // Author: Nicola Asuni
 //
 // (c) Copyright:
 //               Nicola Asuni
-//               Tecnick.com s.r.l.
-//               Via Della Pace, 11
-//               09044 Quartucciu (CA)
-//               ITALY
+//               Tecnick.com LTD
 //               www.tecnick.com
 //               info@tecnick.com
 //============================================================+
@@ -22,55 +19,55 @@
 /**
  * Creates an example PDF TEST document using TCPDF
  * @package com.tecnick.tcpdf
- * @abstract TCPDF - Example: Object Visibility
+ * @abstract TCPDF - Example: Object Visibility and Layers
  * @author Nicola Asuni
- * @copyright 2004-2009 Nicola Asuni - Tecnick.com S.r.l (www.tecnick.com) Via Della Pace, 11 - 09044 - Quartucciu (CA) - ITALY - www.tecnick.com - info@tecnick.com
- * @link http://tcpdf.org
- * @license http://www.gnu.org/copyleft/lesser.html LGPL
  * @since 2008-03-04
  */
 
-require_once('../config/lang/eng.php');
-require_once('../tcpdf.php');
+// Include the main TCPDF library (search for installation path).
+require_once('tcpdf_include.php');
 
 // create new PDF document
 $pdf = new TCPDF(PDF_PAGE_ORIENTATION, PDF_UNIT, PDF_PAGE_FORMAT, true, 'UTF-8', false);
 
 // set document information
-$pdf->SetCreator(PDF_CREATOR);
-$pdf->SetAuthor('Nicola Asuni');
-$pdf->SetTitle('TCPDF Example 024');
-$pdf->SetSubject('TCPDF Tutorial');
-$pdf->SetKeywords('TCPDF, PDF, example, test, guide');
+$pdf->setCreator(PDF_CREATOR);
+$pdf->setAuthor('Nicola Asuni');
+$pdf->setTitle('TCPDF Example 024');
+$pdf->setSubject('TCPDF Tutorial');
+$pdf->setKeywords('TCPDF, PDF, example, test, guide');
 
 // set default header data
-$pdf->SetHeaderData(PDF_HEADER_LOGO, PDF_HEADER_LOGO_WIDTH, PDF_HEADER_TITLE.' 024', PDF_HEADER_STRING);
+$pdf->setHeaderData(PDF_HEADER_LOGO, PDF_HEADER_LOGO_WIDTH, PDF_HEADER_TITLE.' 024', PDF_HEADER_STRING);
 
 // set header and footer fonts
 $pdf->setHeaderFont(Array(PDF_FONT_NAME_MAIN, '', PDF_FONT_SIZE_MAIN));
 $pdf->setFooterFont(Array(PDF_FONT_NAME_DATA, '', PDF_FONT_SIZE_DATA));
 
 // set default monospaced font
-$pdf->SetDefaultMonospacedFont(PDF_FONT_MONOSPACED);
+$pdf->setDefaultMonospacedFont(PDF_FONT_MONOSPACED);
 
-//set margins
-$pdf->SetMargins(PDF_MARGIN_LEFT, PDF_MARGIN_TOP, PDF_MARGIN_RIGHT);
-$pdf->SetHeaderMargin(PDF_MARGIN_HEADER);
-$pdf->SetFooterMargin(PDF_MARGIN_FOOTER);
+// set margins
+$pdf->setMargins(PDF_MARGIN_LEFT, PDF_MARGIN_TOP, PDF_MARGIN_RIGHT);
+$pdf->setHeaderMargin(PDF_MARGIN_HEADER);
+$pdf->setFooterMargin(PDF_MARGIN_FOOTER);
 
-//set auto page breaks
-$pdf->SetAutoPageBreak(TRUE, PDF_MARGIN_BOTTOM);
+// set auto page breaks
+$pdf->setAutoPageBreak(TRUE, PDF_MARGIN_BOTTOM);
 
-//set image scale factor
+// set image scale factor
 $pdf->setImageScale(PDF_IMAGE_SCALE_RATIO);
 
-//set some language-dependent strings
-$pdf->setLanguageArray($l);
+// set some language-dependent strings (optional)
+if (@file_exists(dirname(__FILE__).'/lang/eng.php')) {
+	require_once(dirname(__FILE__).'/lang/eng.php');
+	$pdf->setLanguageArray($l);
+}
 
 // ---------------------------------------------------------
 
 // set font
-$pdf->SetFont('times', '', 18);
+$pdf->setFont('times', '', 18);
 
 // add a page
 $pdf->AddPage();
@@ -88,10 +85,10 @@ Check the print preview of this document to display the alternative text.';
 $pdf->Write(0, $txt, '', 0, '', true, 0, false, false, 0);
 
 // change font size
-$pdf->SetFontSize(40);
+$pdf->setFontSize(40);
 
 // change text color
-$pdf->SetTextColor(0,63,127);
+$pdf->setTextColor(0,63,127);
 
 // set visibility only for screen
 $pdf->setVisibility('screen');
@@ -103,7 +100,7 @@ $pdf->Write(0, '[This line is for display]', '', 0, 'C', true, 0, false, false,
 $pdf->setVisibility('print');
 
 // change text color
-$pdf->SetTextColor(127,0,0);
+$pdf->setTextColor(127,0,0);
 
 // write something only for print
 $pdf->Write(0, '[This line is for printout]', '', 0, 'C', true, 0, false, false, 0);
@@ -113,10 +110,31 @@ $pdf->setVisibility('all');
 
 // ---------------------------------------------------------
 
+// LAYERS
+
+// start a new layer
+$pdf->startLayer('layer1', true, true);
+
+// change font size
+$pdf->setFontSize(18);
+
+// change text color
+$pdf->setTextColor(0,127,0);
+
+$txt = 'Using the startLayer() method you can group PDF objects into layers.
+This text is on "layer1".';
+
+// write something
+$pdf->Write(0, $txt, '', 0, 'L', true, 0, false, false, 0);
+
+// close the current layer
+$pdf->endLayer();
+
+// ---------------------------------------------------------
+
 //Close and output PDF document
-$pdf->Output('example_024.pdf', 'I');
+$pdf->Output('example_024.pdf', 'D');
 
 //============================================================+
-// END OF FILE                                                
+// END OF FILE
 //============================================================+
-?>
