@@ -2,7 +2,7 @@
 //============================================================+
 // File name   : example_050.php
 // Begin       : 2009-04-09
-// Last Update : 2010-06-06
+// Last Update : 2013-05-14
 //
 // Description : Example 050 for TCPDF class
 //               2D Barcodes
@@ -11,10 +11,7 @@
 //
 // (c) Copyright:
 //               Nicola Asuni
-//               Tecnick.com s.r.l.
-//               Via Della Pace, 11
-//               09044 Quartucciu (CA)
-//               ITALY
+//               Tecnick.com LTD
 //               www.tecnick.com
 //               info@tecnick.com
 //============================================================+
@@ -24,59 +21,66 @@
  * @package com.tecnick.tcpdf
  * @abstract TCPDF - Example: 2D barcodes.
  * @author Nicola Asuni
- * @copyright 2004-2009 Nicola Asuni - Tecnick.com S.r.l (www.tecnick.com) Via Della Pace, 11 - 09044 - Quartucciu (CA) - ITALY - www.tecnick.com - info@tecnick.com
- * @link http://tcpdf.org
- * @license http://www.gnu.org/copyleft/lesser.html LGPL
  * @since 2008-03-04
  */
 
-require_once('../config/lang/eng.php');
-require_once('../tcpdf.php');
+// Include the main TCPDF library (search for installation path).
+require_once('tcpdf_include.php');
 
 // create new PDF document
 $pdf = new TCPDF(PDF_PAGE_ORIENTATION, PDF_UNIT, PDF_PAGE_FORMAT, true, 'UTF-8', false);
 
 // set document information
-$pdf->SetCreator(PDF_CREATOR);
-$pdf->SetAuthor('Nicola Asuni');
-$pdf->SetTitle('TCPDF Example 050');
-$pdf->SetSubject('TCPDF Tutorial');
-$pdf->SetKeywords('TCPDF, PDF, example, test, guide');
+$pdf->setCreator(PDF_CREATOR);
+$pdf->setAuthor('Nicola Asuni');
+$pdf->setTitle('TCPDF Example 050');
+$pdf->setSubject('TCPDF Tutorial');
+$pdf->setKeywords('TCPDF, PDF, example, test, guide');
 
 // set default header data
-$pdf->SetHeaderData(PDF_HEADER_LOGO, PDF_HEADER_LOGO_WIDTH, PDF_HEADER_TITLE.' 050', PDF_HEADER_STRING);
+$pdf->setHeaderData(PDF_HEADER_LOGO, PDF_HEADER_LOGO_WIDTH, PDF_HEADER_TITLE.' 050', PDF_HEADER_STRING);
 
 // set header and footer fonts
 $pdf->setHeaderFont(Array(PDF_FONT_NAME_MAIN, '', PDF_FONT_SIZE_MAIN));
 $pdf->setFooterFont(Array(PDF_FONT_NAME_DATA, '', PDF_FONT_SIZE_DATA));
 
 // set default monospaced font
-$pdf->SetDefaultMonospacedFont(PDF_FONT_MONOSPACED);
+$pdf->setDefaultMonospacedFont(PDF_FONT_MONOSPACED);
 
-//set margins
-$pdf->SetMargins(PDF_MARGIN_LEFT, PDF_MARGIN_TOP, PDF_MARGIN_RIGHT);
-$pdf->SetHeaderMargin(PDF_MARGIN_HEADER);
-$pdf->SetFooterMargin(PDF_MARGIN_FOOTER);
+// set margins
+$pdf->setMargins(PDF_MARGIN_LEFT, PDF_MARGIN_TOP, PDF_MARGIN_RIGHT);
+$pdf->setHeaderMargin(PDF_MARGIN_HEADER);
+$pdf->setFooterMargin(PDF_MARGIN_FOOTER);
 
-//set auto page breaks
-$pdf->SetAutoPageBreak(TRUE, PDF_MARGIN_BOTTOM);
+// set auto page breaks
+$pdf->setAutoPageBreak(TRUE, PDF_MARGIN_BOTTOM);
 
-//set image scale factor
+// set image scale factor
 $pdf->setImageScale(PDF_IMAGE_SCALE_RATIO);
 
-//set some language-dependent strings
-$pdf->setLanguageArray($l);
+// set some language-dependent strings (optional)
+if (@file_exists(dirname(__FILE__).'/lang/eng.php')) {
+	require_once(dirname(__FILE__).'/lang/eng.php');
+	$pdf->setLanguageArray($l);
+}
 
 // ---------------------------------------------------------
 
 // NOTE: 2D barcode algorithms must be implemented on 2dbarcode.php class file.
 
 // set font
-$pdf->SetFont('helvetica', '', 10);
+$pdf->setFont('helvetica', '', 11);
 
 // add a page
 $pdf->AddPage();
 
+// print a message
+$txt = "You can also export 2D barcodes in other formats (PNG, SVG, HTML). Check the examples inside the barcode directory.\n";
+$pdf->MultiCell(70, 50, $txt, 0, 'J', false, 1, 125, 30, true, 0, false, true, 0, 'T', false);
+
+
+$pdf->setFont('helvetica', '', 10);
+
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
 // set style for barcode
@@ -91,14 +95,13 @@ $style = array(
 );
 
 // write RAW 2D Barcode
-$pdf->SetXY(30, 30);
-$code = '111011101110111,010010001000010,010011001110010,010010000010010,010011101110010';
-$pdf->write2DBarcode($code, 'RAW', '', '', 30, 20, $style, 'N');
 
-$pdf->SetXY(100, 30);
+$code = '111011101110111,010010001000010,010011001110010,010010000010010,010011101110010';
+$pdf->write2DBarcode($code, 'RAW', 80, 30, 30, 20, $style, 'N');
+
 // write RAW2 2D Barcode
 $code = '[111011101110111][010010001000010][010011001110010][010010000010010][010011101110010]';
-$pdf->write2DBarcode($code, 'RAW2', '', '', 30, 20, $style, 'N');
+$pdf->write2DBarcode($code, 'RAW2', 80, 60, 30, 20, $style, 'N');
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
@@ -114,43 +117,38 @@ $style = array(
 );
 
 // QRCODE,L : QR-CODE Low error correction
-$pdf->SetXY(30, 60);
-$pdf->write2DBarcode('www.tcpdf.org', 'QRCODE,L', '', '', 50, 50, $style, 'N');
-$pdf->Text(30, 55, 'QRCODE L');
+$pdf->write2DBarcode('www.tcpdf.org', 'QRCODE,L', 20, 30, 50, 50, $style, 'N');
+$pdf->Text(20, 25, 'QRCODE L');
 
 // QRCODE,M : QR-CODE Medium error correction
-$pdf->SetXY(100, 60);
-$pdf->write2DBarcode('www.tcpdf.org', 'QRCODE,M', '', '', 50, 50, $style, 'N');
-$pdf->Text(100, 55, 'QRCODE M');
+$pdf->write2DBarcode('www.tcpdf.org', 'QRCODE,M', 20, 90, 50, 50, $style, 'N');
+$pdf->Text(20, 85, 'QRCODE M');
 
 // QRCODE,Q : QR-CODE Better error correction
-$pdf->SetXY(30, 120);
-$pdf->write2DBarcode('www.tcpdf.org', 'QRCODE,Q', '', '', 50, 50, $style, 'N');
-$pdf->Text(30, 115, 'QRCODE Q');
-
+$pdf->write2DBarcode('www.tcpdf.org', 'QRCODE,Q', 20, 150, 50, 50, $style, 'N');
+$pdf->Text(20, 145, 'QRCODE Q');
 
 // QRCODE,H : QR-CODE Best error correction
-$pdf->SetXY(100, 120);
-$pdf->write2DBarcode('www.tcpdf.org', 'QRCODE,H', '', '', 50, 50, $style, 'N');
-$pdf->Text(100, 115, 'QRCODE H');
+$pdf->write2DBarcode('www.tcpdf.org', 'QRCODE,H', 20, 210, 50, 50, $style, 'N');
+$pdf->Text(20, 205, 'QRCODE H');
 
 // -------------------------------------------------------------------
 // PDF417 (ISO/IEC 15438:2006)
 
 /*
 
- The $type parameter can be simple 'PDF417' or 'PDF417' followed by a 
+ The $type parameter can be simple 'PDF417' or 'PDF417' followed by a
  number of comma-separated options:
- 
+
  'PDF417,a,e,t,s,f,o0,o1,o2,o3,o4,o5,o6'
- 
+
  Possible options are:
- 
+
  	a  = aspect ratio (width/height);
  	e  = error correction level (0-8);
- 	
+
  	Macro Control Block options:
- 	
+
  	t  = total number of macro segments;
  	s  = macro segment index (0-99998);
  	f  = file ID;
@@ -161,17 +159,23 @@ $pdf->Text(100, 115, 'QRCODE H');
  	o4 = Addressee (text);
  	o5 = File Size (numeric);
  	o6 = Checksum (numeric).
- 
- Parameters t, s and f are required for a Macro Control Block, all other parametrs are optional.
+
+ Parameters t, s and f are required for a Macro Control Block, all other parameters are optional.
  To use a comma character ',' on text options, replace it with the character 255: "\xff".
 
 */
 
-$pdf->SetXY(30, 180);
-$pdf->write2DBarcode('www.tcpdf.org', 'PDF417', '', '', 0, 30, $style, 'N');
-$pdf->Text(30, 175, 'PDF417 (ISO/IEC 15438:2006)');
+$pdf->write2DBarcode('www.tcpdf.org', 'PDF417', 80, 90, 0, 30, $style, 'N');
+$pdf->Text(80, 85, 'PDF417 (ISO/IEC 15438:2006)');
 
 // -------------------------------------------------------------------
+// DATAMATRIX (ISO/IEC 16022:2006)
+
+$pdf->write2DBarcode('http://www.tcpdf.org', 'DATAMATRIX', 80, 150, 50, 50, $style, 'N');
+$pdf->Text(80, 145, 'DATAMATRIX (ISO/IEC 16022:2006)');
+
+// -------------------------------------------------------------------
+
 // new style
 $style = array(
 	'border' => 2,
@@ -181,9 +185,8 @@ $style = array(
 );
 
 // QRCODE,H : QR-CODE Best error correction
-$pdf->SetXY(30, 220);
-$pdf->write2DBarcode('www.tcpdf.org', 'QRCODE,H', '', '', 50, 50, $style, 'N');
-$pdf->Text(30, 215, 'QRCODE H - COLORED');
+$pdf->write2DBarcode('www.tcpdf.org', 'QRCODE,H', 80, 210, 50, 50, $style, 'N');
+$pdf->Text(80, 205, 'QRCODE H - COLORED');
 
 // new style
 $style = array(
@@ -194,9 +197,8 @@ $style = array(
 );
 
 // QRCODE,H : QR-CODE Best error correction
-$pdf->SetXY(100, 220);
-$pdf->write2DBarcode('www.tcpdf.org', 'QRCODE,H', '', '', 50, 50, $style, 'N');
-$pdf->Text(100, 215, 'QRCODE H - NO PADDING');
+$pdf->write2DBarcode('www.tcpdf.org', 'QRCODE,H', 140, 210, 50, 50, $style, 'N');
+$pdf->Text(140, 205, 'QRCODE H - NO PADDING');
 
 // ---------------------------------------------------------
 
@@ -206,4 +208,3 @@ $pdf->Output('example_050.pdf', 'I');
 //============================================================+
 // END OF FILE
 //============================================================+
-?>
